@@ -92,8 +92,14 @@ def api_extract_batch(vars, request, retries=5) -> DataFrame:
                     # Census Tract GEOID: STATE+COUNTY+TRACT (2+3+6 digits)
                     tract.append(k[len(k) - 3] + k[len(k) - 2] + k[len(k) - 1])
                     
+                    if 'county' not in data:
+                        data['county'] = []
                     data['county'].append(k[len(k) - 2])
+                    
+                    if 'state' not in data:
+                        data['state'] = []
                     data['state'].append(k[len(k) - 3])
+                    
                     # start with the second piece of json data, first piece is not needed
                     json_data_index = 1
                     for var in vars:
